Natural Earth » Blog Archive » Coastline - Free vector and raster map data at 1:10m, 1:50m, and 1:110m scales

#

Free vector and raster map data at 1:10m, 1:50m, and 1:110m scales
Search for:

- Home
- Features
- Downloads
- Blog
- Issues
- Corrections
- About

## Coastline

Includes major islands.
Download coastline (2.93 MB) version 4.1.0

About

Ocean coastline, including major islands. Coastline is matched to land and water polygons. The Caspian Sea, which is technically a lake, is included. The ocean coastline, the foundation for building all of NEV, primarily derives from World Data Bank 2 with modest generalization applied via line simplification in Adobe Illustrator. The Antarctica coast derives from NASA Mosaic of Antarctica.

(below) Yucatan peninsula, Cuba, and Hispaniola.

Issues

World Data Bank 2 coastlines have suspect accuracy for certain parts of the world, including northern Russia, southern Chile, and most egregiously, the west coast of the United States extending to the Baja Peninsula, Mexico, where the coast was approximately 7 km east of where it should be. The west coast of the US was corrected on NEV; other areas were not.

Does not include rank 6, 7, or 8 coastlines from the minor islands. Some rank 5 coastline should be reclassified as rank 6.

Resources

- World Data Bank 2
- Mosaic of Antarctica

Version History

- 4.1.0
- 4.0.0
- 3.0.0
- 2.0.0
- 1.3.0
- 1.1.0
- 1.0.0

The master changelog is available on Github »

This entry was posted on Tuesday, November 17th, 2009 at 12:01 am and is filed under 10m-physical-vectors. You can follow any responses to this entry through the RSS 2.0 feed. Both comments and pings are currently closed.

Comments are closed.